/**
 * 判断路由是否可以加入
 * @param  {[type]}  route          [单个路由]
 * @param  {[type]}  roleRouterMap  [静态路由数组]
 * @return {Boolean}                [是否存在]
 */
function isPermission(route, routenamearr) {
  if (route && routenamearr) {
    return routenamearr.some((item) => {
      return item.permissionCode === route.code
    })
  } else {
    return false
  }
}
/**
 * 递归过滤菜单
 * @param  {[object]} TopNavRouterMap [全部路由]
 * @param  {[object]} roleRouterMap   [当前有权限的路由]
 * @return {[object]}                 [实际产出路由]
 */
function filterRouter(RouterMap, roleRouterMap) {
  const accessedRouters = RouterMap.filter(route => {
    if (isPermission(route, roleRouterMap)) {
      if (route.auPermissionChild) {
        roleRouterMap.forEach((item) => {
          if (item.permissionCode === route.code) {
            route.children = filterRouter(route.auPermissionChild, item.auPermissionChild) || []
          }
        })
      }
      return true
    }
    return false
  })
  return accessedRouters
}
/**
 * 处理二级单个菜单
 * @param  {[object]} siderRouterMap  [全部二级三级路由]
 * @return {[object]}                 [实际产出二级三级路由]
 */
function filterSiderRouter(siderRouterMap) {
  // 重构二级菜单
  return siderRouterMap.filter((parentitem) => {
    return parentitem.filter((item) => {
      if (item.viewpath !== undefined) {
        item.component = item.viewpath
        item.children = item
        delete item['viewpath']
        delete item['children']
        console.log(item)
      }
      return true
    })
  })
}
function GenerateRoutes({ commit }, data, RouterMap) {
  return new Promise(resolve => {
    const roleRouter = filterRouter(RouterMap, data.permission) // 获取可用路由
    commit('SET_PERMISSION', roleRouter) // 路由存入状态
    const addRoutelist = [] // 二级三级菜单
    roleRouter.forEach((item) => {
      addRoutelist.push(item.children)
    })
    // 重构二级菜单
    if (roleRouter === []) {
      const siderlist = filterSiderRouter(addRoutelist) // 处理单个二级路由
      console.log('变化后', siderlist)
    }
    // console.log(data.permission)
    commit('SET_ROUTERS', addRoutelist[data.topnav])
    resolve()
  })
}
module.exports = {
  filterSiderRouter: filterSiderRouter,
  filterRouter: filterRouter,
  isPermission: isPermission,
  GenerateRoutes: GenerateRoutes
}